Skip to contents

Crimes and Clearances are reported monthly by LEAs throughout the state. The data is reported as part of the Federal Bureau of Investigation's (FBI), Uniform Crime Reporting (UCR) Program and includes the number of actual offenses as well as the number of clearances as per the UCR guidelines. Supplemental data are also collected on the nature of some of the crime types and the value of property stolen and recovered. The information is used to provide statistical data on the offenses of: criminal homicide, rape, robbery, aggravated assault, burglary, larceny-theft, motor vehicle theft, and arson.

Usage

ca_crimes_and_clearances

Format

An object of class data.frame with 27853 rows and 70 columns.